
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef jloco_MSG_LIB_H
#define jloco_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "jlocoType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  JLOCO_MBOX_NAME                  genomInstanceName("jloco")

#define  JLOCO_MAX_RQST_SIZE              128

#define  JLOCO_MBOX_RQST_SIZE       \
 (BUF_SIZE(JLOCO_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  JLOCO_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  JLOCO_MAX_REPLY_SIZE             128

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  JLOCO_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(JLOCO_MAX_REPLY_SIZE) \
   + BUF_SIZE(JLOCO_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define JLOCO_INIT_RQST 0
#define JLOCO_SETWATCHDOGTOLERANCE_RQST 1
#define JLOCO_GETWATCHDOGTOLERANCE_RQST 2
#define JLOCO_SETCMDPARAM_RQST 3
#define JLOCO_GETCMDPARAM_RQST 4
#define JLOCO_SETODOCORRECTION_RQST 5
#define JLOCO_GETODOCORRECTION_RQST 6
#define JLOCO_SETVARPARAMS_RQST 7
#define JLOCO_SETPOS_RQST 8
#define JLOCO_SETPOSERR_RQST 9
#define JLOCO_SETGYROMODE_RQST 10
#define JLOCO_GETGYROMODE_RQST 11
#define JLOCO_JOYSTICKON_RQST 12
#define JLOCO_TRACKSTART_RQST 13
#define JLOCO_TRACKSPEEDSTART_RQST 14
#define JLOCO_TRACKEND_RQST 15
#define JLOCO_SETPOM_RQST 16
#define JLOCO_ABORT_RQST 17


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS jlocoClientInit (CLIENT_ID *pClientId);

STATUS jlocoClientEnd (CLIENT_ID clientId);

int jlocoAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int jlocoAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int jlocoAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS jlocoInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int jlocoInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int jlocoInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int jlocoInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS jlocoSetWatchdogToleranceRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_watchdogTolerance),
					 int replyTimeOut);

int jlocoSetWatchdogToleranceReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetWatchdogToleranceRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_watchdogTolerance), 
				 
				 int *bilan);




extern STATUS jlocoGetWatchdogToleranceRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int jlocoGetWatchdogToleranceReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       int *(out_watchdogTolerance),
			       int *bilan);

int jlocoGetWatchdogToleranceRqstAndRcv (CLIENT_ID clientId, 
				  
				 int *(out_watchdogTolerance),
				 int *bilan);




extern STATUS jlocoSetCmdParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_CMD_PARAM *(in_cmdParam),
					 int replyTimeOut);

int jlocoSetCmdParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetCmdParamRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_CMD_PARAM *(in_cmdParam), 
				 
				 int *bilan);




extern STATUS jlocoGetCmdParamRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int jlocoGetCmdParamReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GENPOS_CART_CMD_PARAM *(out_cmdParam),
			       int *bilan);

int jlocoGetCmdParamRqstAndRcv (CLIENT_ID clientId, 
				  
				 GENPOS_CART_CMD_PARAM *(out_cmdParam),
				 int *bilan);




extern STATUS jlocoSetOdoCorrectionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 JLOCO_ODO_CORRECTION *(in_tmpOdoCorr),
					 int replyTimeOut);

int jlocoSetOdoCorrectionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetOdoCorrectionRqstAndRcv (CLIENT_ID clientId, 
				 JLOCO_ODO_CORRECTION *(in_tmpOdoCorr), 
				 
				 int *bilan);




extern STATUS jlocoGetOdoCorrectionRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int jlocoGetOdoCorrectionReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       JLOCO_ODO_CORRECTION *(out_tmpOdoCorr),
			       int *bilan);

int jlocoGetOdoCorrectionRqstAndRcv (CLIENT_ID clientId, 
				  
				 JLOCO_ODO_CORRECTION *(out_tmpOdoCorr),
				 int *bilan);




extern STATUS jlocoSetVarParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 JLOCO_VAR_PARAMS *(in_varParams),
					 int replyTimeOut);

int jlocoSetVarParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetVarParamsRqstAndRcv (CLIENT_ID clientId, 
				 JLOCO_VAR_PARAMS *(in_varParams), 
				 
				 int *bilan);




extern STATUS jlocoSetPosRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_CONFIG *(in_tmpPose),
					 int replyTimeOut);

int jlocoSetPosReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetPosRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_CONFIG *(in_tmpPose), 
				 
				 int *bilan);




extern STATUS jlocoSetPosErrRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GENPOS_CART_CONFIG_VAR *(in_tmpErr),
					 int replyTimeOut);

int jlocoSetPosErrReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetPosErrRqstAndRcv (CLIENT_ID clientId, 
				 GENPOS_CART_CONFIG_VAR *(in_tmpErr), 
				 
				 int *bilan);




extern STATUS jlocoSetGyroModeRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 int *(in_gyroMode),
					 int replyTimeOut);

int jlocoSetGyroModeReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoSetGyroModeRqstAndRcv (CLIENT_ID clientId, 
				 int *(in_gyroMode), 
				 
				 int *bilan);




extern STATUS jlocoGetGyroModeRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int jlocoGetGyroModeReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       int *(out_gyroMode),
			       int *bilan);

int jlocoGetGyroModeRqstAndRcv (CLIENT_ID clientId, 
				  
				 int *(out_gyroMode),
				 int *bilan);




extern STATUS jlocoJoystickOnRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int jlocoJoystickOnReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int jlocoJoystickOnRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int jlocoJoystickOnRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS jlocoTrackStartRqstSend (CLIENT_ID clientId, int *pRqstId,
					 JLOCO_NAME *(in_posterName),
					 int replyTimeOut);

extern int jlocoTrackStartReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int jlocoTrackStartRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					JLOCO_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int jlocoTrackStartRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					JLOCO_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS jlocoTrackSpeedStartRqstSend (CLIENT_ID clientId, int *pRqstId,
					 JLOCO_NAME *(in_posterName),
					 int replyTimeOut);

extern int jlocoTrackSpeedStartReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int jlocoTrackSpeedStartRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					JLOCO_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int jlocoTrackSpeedStartRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					JLOCO_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS jlocoTrackEndRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int jlocoTrackEndReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int jlocoTrackEndRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS jlocoSetPomRqstSend (CLIENT_ID clientId, int *pRqstId,
					 JLOCO_NAME *(in_posterName),
					 int replyTimeOut);

extern int jlocoSetPomReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int jlocoSetPomRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					JLOCO_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int jlocoSetPomRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					JLOCO_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* jloco_MSG_LIB_H */

